==> pogamut-ut3-3.5.4-20140508.024434-62-sources.jar: cz/cuni/amis/pogamut/ut3/agent/module/sensor/UT3Visibility.java <==
/*
 * Copyright (C) 2014 AMIS research group, Faculty of Mathematics and Physics, Charles University in Prague, Czech Republic
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package cz.cuni.amis.pogamut.ut3.agent.module.sensor;

import cz.cuni.amis.pogamut.base.communication.worldview.IWorldView;
import cz.cuni.amis.pogamut.base.communication.worldview.event.IWorldEventListener;
import cz.cuni.amis.pogamut.unreal.communication.messages.UnrealId;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.AgentInfo;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.visibility.Visibility;
import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004Bot;
import cz.cuni.amis.pogamut.ut2004.communication.messages.ItemType;
import cz.cuni.amis.pogamut.ut2004.communication.messages.gbinfomessages.SeeVolume;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.logging.Logger;

/**
 *
 * @author Evers
 */
public class UT3Visibility extends Visibility {
        
        /**
         * Returns the unreal id's of the given itemtype.
         * TODO: Add getVisibleVolumes
         */
        public ArrayList<UnrealId> getVisibleVolumeNavPoints(ItemType itemType) {
                if(seeVolumeListener.visible.containsKey(itemType))
                        return seeVolumeListener.visible.get(itemType);
                else
                        return new ArrayList<UnrealId>();
        }

        private class SeeVolumeListener implements IWorldEventListener<SeeVolume>
        {
                private HashMap<ItemType, ArrayList<UnrealId>> visible = new HashMap<ItemType, ArrayList<UnrealId>>();
                
                @Override
                public void notify(SeeVolume event)
                {
                        // get the type of volume
                        if(!visible.containsKey(event.getType()))
                                visible.put(event.getType(), new ArrayList<UnrealId>());
                        ArrayList<UnrealId> ids = visible.get(event.getType());
                        // get the corresponding ids
                        if(event.isVisible() && !ids.contains(event.getId()))
                                ids.add(event.getId());
                        if(!event.isVisible() && ids.contains(event.getId()))
                                ids.remove(event.getId());
                }
                
                public SeeVolumeListener(IWorldView worldView)
                {
                        worldView.addEventListener(SeeVolume.class, this);
                }
        }
       
        SeeVolumeListener seeVolumeListener;
        
        public UT3Visibility(UT2004Bot bot, AgentInfo info) {
		this(bot, info, null);
	}
        
        public UT3Visibility(UT2004Bot bot, AgentInfo info, Logger log)
        {
                super(bot, info, log);
                seeVolumeListener = new SeeVolumeListener(worldView);
        }        
}

==> pogamut-ut3-3.6.1-20140518.025525-10-sources.jar: cz/cuni/amis/pogamut/ut3/agent/module/sensor/UT3Visibility.java <==
/*
 * Copyright (C) 2014 AMIS research group, Faculty of Mathematics and Physics, Charles University in Prague, Czech Republic
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package cz.cuni.amis.pogamut.ut3.agent.module.sensor;

import cz.cuni.amis.pogamut.base.communication.worldview.IWorldView;
import cz.cuni.amis.pogamut.base.communication.worldview.event.IWorldEventListener;
import cz.cuni.amis.pogamut.unreal.communication.messages.UnrealId;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.AgentInfo;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.visibility.Visibility;
import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004Bot;
import cz.cuni.amis.pogamut.ut2004.communication.messages.ItemType;
//import cz.cuni.amis.pogamut.ut2004.communication.messages.gbinfomessages.SeeVolume;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.logging.Logger;

/**
 *
 * @author Evers
 */
public class UT3Visibility extends Visibility {
        
        /**
         * Returns the unreal id's of the given itemtype.
         * TODO: Add getVisibleVolumes
         */
    /*
        public ArrayList<UnrealId> getVisibleVolumeNavPoints(ItemType itemType) {
                if(seeVolumeListener.visible.containsKey(itemType))
                        return seeVolumeListener.visible.get(itemType);
                else
                        return new ArrayList<UnrealId>();
        }

        private class SeeVolumeListener implements IWorldEventListener<SeeVolume>
        {
                private HashMap<ItemType, ArrayList<UnrealId>> visible = new HashMap<ItemType, ArrayList<UnrealId>>();
                
                @Override
                public void notify(SeeVolume event)
                {
                        // get the type of volume
                        if(!visible.containsKey(event.getType()))
                                visible.put(event.getType(), new ArrayList<UnrealId>());
                        ArrayList<UnrealId> ids = visible.get(event.getType());
                        // get the corresponding ids
                        if(event.isVisible() && !ids.contains(event.getId()))
                                ids.add(event.getId());
                        if(!event.isVisible() && ids.contains(event.getId()))
                                ids.remove(event.getId());
                }
                
                public SeeVolumeListener(IWorldView worldView)
                {
                        worldView.addEventListener(SeeVolume.class, this);
                }
        }
       
        SeeVolumeListener seeVolumeListener;
        */
        public UT3Visibility(UT2004Bot bot, AgentInfo info) {
		this(bot, info, null);
	}
        
        public UT3Visibility(UT2004Bot bot, AgentInfo info, Logger log)
        {
                super(bot, info, log);
                //seeVolumeListener = new SeeVolumeListener(worldView);
        }        
}
